@@ -2,6 +2,7 @@ import { defineMessages, injectIntl, FormattedMessage } from 'react-intl';
 import { connect } from 'react-redux';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import Formsy from 'formsy-react';
+import PropTypes from 'prop-types';
 import React from 'react';
 import ReactDOM from 'react-dom';
 
@@ -40,8 +41,8 @@ const messages = defineMessages({
   },
   description: {
     id: 'Login.description',
-    defaultMessage: 'This tool will walk you through the process of configuring and '
-                     + 'deploying an OpenStack environment.'
+    defaultMessage: 'This tool will walk you through the process of configuring and ' +
+      'deploying an OpenStack environment.'
   }
 });
 
@@ -90,43 +91,53 @@ class Login extends React.Component {
     return (
       <div>
         <span id="badge">
-          <img src={LogoSvg} alt="TripleO"></img>
+          <img src={LogoSvg} alt="TripleO" />
         </span>
         <div className="container">
           <div className="row">
             <div className="col-sm-12">
               <div id="brand">
-                <img src={TripleoOwlSvg} alt="TripleO"></img>
+                <img src={TripleoOwlSvg} alt="TripleO" />
               </div>
             </div>
             <div className="col-sm-7 col-md-6 col-lg-5 login">
-              <FormErrorList errors={this.props.formErrors.toJS()}/>
-              <Formsy.Form ref="form"
-                           role="form"
-                           className="form-horizontal"
-                           onSubmit={this.handleLogin.bind(this)}
-                           onValid={this._enableButton.bind(this)}
-                           onInvalid={this._disableButton.bind(this)}>
-                <LoginInput name="username"
-                            placeholder={formatMessage(messages.username)}
-                            title={formatMessage(messages.username)}
-                            validationError={formatMessage(messages.usernameRequired)}
-                            required
-                            autoFocus/>
-                <LoginInput type="password"
-                            name="password"
-                            placeholder={formatMessage(messages.password)}
-                            title={formatMessage(messages.password)}
-                            validationError={formatMessage(messages.passwordRequired)}
-                            required/>
+              <FormErrorList errors={this.props.formErrors.toJS()} />
+              <Formsy.Form
+                ref="form"
+                role="form"
+                className="form-horizontal"
+                onSubmit={this.handleLogin.bind(this)}
+                onValid={this._enableButton.bind(this)}
+                onInvalid={this._disableButton.bind(this)}
+              >
+                <LoginInput
+                  name="username"
+                  placeholder={formatMessage(messages.username)}
+                  title={formatMessage(messages.username)}
+                  validationError={formatMessage(messages.usernameRequired)}
+                  required
+                  autoFocus
+                />
+                <LoginInput
+                  type="password"
+                  name="password"
+                  placeholder={formatMessage(messages.password)}
+                  title={formatMessage(messages.password)}
+                  validationError={formatMessage(messages.passwordRequired)}
+                  required
+                />
                 <div className="form-group">
                   <div className="col-xs-offset-8 col-xs-4 col-sm-4 col-md-4 submit">
-                    <button type="submit"
-                            disabled={!this.state.canSubmit || this.props.isAuthenticating}
-                            className="btn btn-primary btn-lg"
-                            tabIndex="4"
-                            id="Login__loginButton">
-                      <FormattedMessage {...messages.login}/>
+                    <button
+                      type="submit"
+                      disabled={
+                        !this.state.canSubmit || this.props.isAuthenticating
+                      }
+                      className="btn btn-primary btn-lg"
+                      tabIndex="4"
+                      id="Login__loginButton"
+                    >
+                      <FormattedMessage {...messages.login} />
                     </button>
                   </div>
                 </div>
@@ -134,8 +145,9 @@ class Login extends React.Component {
             </div>
             <div className="col-sm-5 col-md-6 col-lg-7 details">
               <p>
-                <strong><FormattedMessage {...messages.welcome}/></strong><br/>
-                <FormattedMessage {...messages.description}/>
+                <strong><FormattedMessage {...messages.welcome} /></strong>
+                <br />
+                <FormattedMessage {...messages.description} />
               </p>
             </div>
           </div>
@@ -146,13 +158,13 @@ class Login extends React.Component {
   }
 }
 Login.propTypes = {
-  dispatch: React.PropTypes.func.isRequired,
+  dispatch: PropTypes.func.isRequired,
   formErrors: ImmutablePropTypes.list.isRequired,
   formFieldErrors: ImmutablePropTypes.map.isRequired,
-  intl: React.PropTypes.object,
-  isAuthenticating: React.PropTypes.bool.isRequired,
-  location: React.PropTypes.object,
-  userLoggedIn: React.PropTypes.bool.isRequired
+  intl: PropTypes.object,
+  isAuthenticating: PropTypes.bool.isRequired,
+  location: PropTypes.object,
+  userLoggedIn: PropTypes.bool.isRequired
 };
 
 function mapStateToProps(state) {
