@@ -1,6 +1,7 @@
 import { defineMessages, FormattedMessage } from 'react-intl';
 import { Link } from 'react-router';
-import React, { PropTypes } from 'react';
+import PropTypes from 'prop-types';
+import React from 'react';
 
 import DeploymentConfigurationSummary from './DeploymentConfigurationSummary';
 
@@ -11,13 +12,13 @@ const messages = defineMessages({
   }
 });
 
-const ConfigurePlanStep = (props) => {
+const ConfigurePlanStep = props => {
   return (
     <div>
-      <DeploymentConfigurationSummary { ...props } />
+      <DeploymentConfigurationSummary {...props} />
       &nbsp;
       <Link to="/deployment-plan/configuration">
-        <FormattedMessage { ...messages.editConfigurationLink} />
+        <FormattedMessage {...messages.editConfigurationLink} />
       </Link>
     </div>
   );
