@@ -1,5 +1,6 @@
 import ClassNames from 'classnames';
-import React, { PropTypes } from 'react';
+import PropTypes from 'prop-types';
+import React from 'react';
 
 export default class DropdownButton extends React.Component {
   handleClick(e) {
@@ -9,11 +10,13 @@ export default class DropdownButton extends React.Component {
 
   render() {
     return (
-      <button className={ClassNames('btn dropdown-toggle', this.props.className)}
-              onClick={this.handleClick.bind(this)}
-              type="button">
+      <button
+        className={ClassNames('btn dropdown-toggle', this.props.className)}
+        onClick={this.handleClick.bind(this)}
+        type="button"
+      >
         {this.props.children}
-        <span className="caret"/>
+        <span className="caret" />
       </button>
     );
   }
