@@ -1,10 +1,15 @@
 import { DropdownButton } from 'react-bootstrap';
-import React, { PropTypes } from 'react';
+import PropTypes from 'prop-types';
+import React from 'react';
 
-const DropdownSelect = (props) => {
+const DropdownSelect = props => {
   const { children, input: { name, onChange, value } } = props;
   return (
-    <DropdownButton id={name} title={value} onSelect={(evKey, ev) => onChange(evKey)}>
+    <DropdownButton
+      id={name}
+      title={value}
+      onSelect={(evKey, ev) => onChange(evKey)}
+    >
       {children}
     </DropdownButton>
   );
